@@ -1,20 +1,8 @@
-/*******************************************************************************
-  Copyright 2008 Ian Wadham <iandw.au@gmail.com>
+/*
+    SPDX-FileCopyrightText: 2008 Ian Wadham <iandw.au@gmail.com>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License
-  along with this program; if not, write to the Free Software
-  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-*******************************************************************************/
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 // Local includes
 #include "game.h"
@@ -43,6 +31,7 @@ Game::Game (Kubrick * parent)
 	  smMoveSlice       (0),
 	  smMoveDirection   (CLOCKWISE),
 
+	  random(QDateTime::currentMSecsSinceEpoch()),
 	  cubeAligned       (true),
           moveIndex         (-1)
 {
@@ -53,8 +42,6 @@ Game::Game (Kubrick * parent)
 
     smInitInput();			// Initialise the move-text parsing.
 
-    random.setSeed (0);			// Zero gets us an arbitrary seed.
-
     setDefaults ();			// Set all options to default values.
     restoreState ();			// Restore the last cube and its state.
     demoPhase = false;			// No demo yet.
@@ -183,7 +170,7 @@ void Game::load ()
     KConfig config (loadFilename, KConfig::SimpleConfig);
 
     if (! config.hasGroup ("KubrickGame")) {
-	KMessageBox::sorry(mainWindow,
+	KMessageBox::error(mainWindow,
                            i18n("The file '%1' is not a valid Kubrick game-file.", loadFilename));
 	return;
     }
@@ -570,7 +557,7 @@ void Game::addPlayersMove (Move * move)
 void Game::smShowSingmasterMoves()
 {
     // Display or re-display the Singmaster moves, if the GUI has been set up.
-    if (mainWindow != 0) {
+    if (mainWindow != nullptr) {
 	mainWindow->setSingmaster (singmasterString + smTempString);
 	mainWindow->setSingmasterSelection
 			(smSelectionStart, smSelectionLength);
@@ -932,7 +919,7 @@ void Game::setSceneLabels ()
     frontVL->setVisible (false);
     backVL->setVisible  (false);
 
-    for (CubeView * v : qAsConst(cubeViews)) {
+    for (CubeView * v : std::as_const(cubeViews)) {
 	if ((v->sceneID != currentSceneID) || (v->label == NoLabel))
 	    continue;			// Skip unwanted scene IDs and labels.
 
@@ -1092,7 +1079,7 @@ void Game::drawScene ()
     float fieldHeight = -cubeCentreZ * 2.0 * tan (3.14159 * viewAngle/360.0);
     float fieldWidth  = aspect * fieldHeight;
 
-    for (CubeView * v : qAsConst(cubeViews)) {
+    for (CubeView * v : std::as_const(cubeViews)) {
 	if (v->sceneID != currentSceneID)
 	    continue;			// Skip unwanted scene IDs.
 
@@ -1201,7 +1188,7 @@ void Game::startDemo ()
 
 void Game::randomDemo ()
 {
-    double pickShape = random.getDouble ();
+    double pickShape = random.generateDouble();
 
     // Pick cubes 40% of the time.
     cubeSize [X] = pickANumber (2, 6);
@@ -1404,7 +1391,7 @@ void Game::savePuzzle (KConfig & config)
     // Save the list of moves, using names "m) 001", "m) 002", etc.
     int n = 0;
     list.clear ();
-    for (Move * m : qAsConst(moves)) {
+    for (Move * m : std::as_const(moves)) {
 	list.append (QString::asprintf ("%d", (int) m->axis));
 	list.append (QString::asprintf ("%d", m->slice));
 	list.append (QString::asprintf ("%d", (int) m->direction));
@@ -1472,12 +1459,12 @@ void Game::loadPuzzle (KConfig & config)
     newCube (option [optXDim], option [optYDim], option [optZDim], 0);
 
     moveSpeed		= option [optMoveSpeed];
-    if (gameGLView != 0) {
+    if (gameGLView != nullptr) {
 	gameGLView->setBevelAmount (option [optBevel]);
     }
     tumbling		= option [optTumbling];
     tumblingTicks	= option [optTumblingTicks];
-    if (mainWindow != 0) {
+    if (mainWindow != nullptr) {
 	// mainWindow->setToggle ("toggle_tumbling", tumbling);
 	mainWindow->setToggle ("watch_shuffling", (bool)option[optViewShuffle]);
 	mainWindow->setToggle ("watch_moves",     (bool)option[optViewMoves]);
@@ -1527,7 +1514,7 @@ void Game::loadPuzzle (KConfig & config)
 	startAnimation (dSeq, option [optSceneID], false, false);
     }
 
-    if (gameGLView != 0) {
+    if (gameGLView != nullptr) {
 	advance ();			// Do all moves or just one anim step.
 	chooseMousePointer ();		// Choose busy or idle mouse pointer.
 	setSceneLabels ();		// Position the labels.
@@ -1631,7 +1618,7 @@ void Game::handleMouseEvent (MouseEvent event, int button, int mX, int mY)
 int Game::pickANumber (int lo, int hi)
 {
     // Pick an integer in the range (lo..hi).
-    return (lo + (int) random.getLong (hi - lo + 1));
+    return random.bounded(lo, hi + 1);
 }
 
 
@@ -1696,7 +1683,7 @@ void Game::startAnimation (const QString &dSeq, int sID, bool vShuffle, bool vMo
     // Set the scene ID, animation display sequence and whether to animate the
     // shuffle and/or player moves or do them instantly (within one tick).
 
-    if ((sID != currentSceneID) && (mainWindow != 0)) {
+    if ((sID != currentSceneID) && (mainWindow != nullptr)) {
         changeScene (sID);
 	currentSceneID  = sID;
     }
